@@ -4,14 +4,13 @@ package Classifier::MailParse;
 #
 # MailParse.pm --- Parse a mail message or messages into words
 #
-# Copyright (c) 2001-2004 John Graham-Cumming
+# Copyright (c) 2001-2006 John Graham-Cumming
 #
 #   This file is part of POPFile
 #
-#   POPFile is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
+#   POPFile is free software; you can redistribute it and/or modify it
+#   under the terms of version 2 of the GNU General Public License as
+#   published by the Free Software Foundation.
 #
 #   POPFile is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1538,6 +1537,20 @@ sub start_parse
 
     $self->{colorized__} = '';
     $self->{colorized__} .= "<tt>" if ( $self->{color__} ne '' );
+
+    # Since Text::Kakasi is not thread-safe, we use it under the
+    # control of a Mutex to avoid a crash if we are running on
+    # Windows.
+
+    if ( $self->{lang__} eq 'Nihongo' ) {
+        if ( $self->{need_kakasi_mutex__} ) {
+            require POPFile::Mutex;
+            $self->{kakasi_mutex__}->acquire();
+        }
+
+        # Open Kakasi dictionary and initialize
+        init_kakasi();
+    }
 }
 
 # ----------------------------------------------------------------------------
@@ -1573,6 +1586,16 @@ sub stop_parse
     }
 
     $self->{in_html_tag__} = 0;
+
+    if ( $self->{lang__} eq 'Nihongo' ) {
+        # Close Kakasi dictionary
+        close_kakasi();
+
+        if ( $self->{need_kakasi_mutex__} ) {
+            require POPFile::Mutex;
+            $self->{kakasi_mutex__}->release();
+        }
+    }
 }
 
 # ----------------------------------------------------------------------------
@@ -1614,6 +1637,7 @@ sub parse_line
                     }
                 }
                 $line = decode_qp( $line );
+                $line =~ s/\x00/NUL/g;
             }
 
             # Decode \x??
@@ -1702,6 +1726,9 @@ sub parse_line
 
                     print "Hit MIME boundary --$1\n" if $self->{debug__};
 
+                    # Decode base64 for every part.
+                    $self->{colorized__} .= $self->clear_out_base64() . "\n\n";
+
                     $self->{in_headers__} = 1;
                 } else {
 
@@ -1782,6 +1809,12 @@ sub clear_out_base64
         print "Base64 data: " . $self->{base64__} . "\n" if ($self->{debug__});
 
         $decoded = decode_base64( $self->{base64__} );
+
+        if ( $self->{lang__} eq 'Nihongo' ) {
+            $decoded = convert_encoding( $decoded, $self->{charset__}, 'euc-jp', '7bit-jis', @{$encoding_candidates{$self->{lang__}}} );
+            $decoded = parse_line_with_kakasi( $self, $decoded );
+        }
+
         $self->parse_html( $decoded, 1 );
 
         print "Decoded: " . $decoded . "\n" if ($self->{debug__});
@@ -1841,12 +1874,12 @@ sub decode_string
         
         $output .= $pre unless ($last_is_encoded && defined($atom) # Per RFC 2047 section 6.2
                                     && $pre =~ /^[\t ]+$/);
-        
+
         if (defined($atom)) {
             if ($encoding eq "B" || $encoding eq "b") {
-                        
+
                 $value = decode_base64( $value );
-    
+
                 # for Japanese header
                 if ($lang eq 'Nihongo') {
                     $value = convert_encoding( $value, $charset, 'euc-jp', '7bit-jis', @{$encoding_candidates{$self->{lang__}}} );
@@ -1856,7 +1889,8 @@ sub decode_string
             elsif ($encoding eq "Q" || $encoding eq "q") {
                 $value =~ s/\_/=20/g;
                 $value = decode_qp( $value );
-    
+                $value =~ s/\x00/NUL/g;
+
                 # for Japanese header
                 if ($lang eq 'Nihongo') {
                     $value = convert_encoding( $value, $charset, 'euc-jp', '7bit-jis', @{$encoding_candidates{$self->{lang__}}} );
@@ -1868,10 +1902,10 @@ sub decode_string
         }
         $output .= $value || '';
     }
-    
+
     # grab the unmatched tail (thanks to /gc and \G)
     $output .= $1 if ($mystring =~ m/\G(.*)/g);
-    
+
     return $output;
 }
 
@@ -2373,7 +2407,7 @@ sub handle_disposition
 
     my ( $attachment, $filename ) = $self->match_attachment_filename( $params );
 
-    if ( $attachment eq 'attachment' ) {
+    if ( defined( $attachment ) && ( $attachment eq 'attachment' ) ) {
         $self->add_attachment_filename( $filename ) ;
     }
 }
@@ -2495,42 +2529,49 @@ sub parse_line_with_kakasi
 {
     my ( $self, $line ) = @_;
 
+    # If the line does not contain Japanese characters, do nothing
+    return $line if ( $line =~ /^[\x00-\x7F]*$/ );
+
     # This is used to parse Japanese
     require Text::Kakasi;
 
-    # Split Japanese line into words using Kakasi Wakachigaki
-    # mode(-w is passed to Kakasi as argument). Both input and ouput
-    # encoding are EUC-JP.
-    #
-    # Since Text::Kakasi is not thread-safe, we use it under the
-    # control of a semaphore to avoid a crash if we are running on
-    # Windows in a forked process.  
-    #
-    # Note that this requires us to detect a sub-process by looking at
-    # the value of $$.  In ActivePerl a negative PID is in a
-    # sub-process If this were to change then this code would not
-    # work.
-
-    my $need_semaphore = ( ( $^O eq 'MSWin32' ) && ( $$ < 0 ) );
-
-    if ( $need_semaphore ) {
-        if ( !defined( $self->{mutex__} ) ) {
-   	    require POPFile::Mutex;
-  	    $self->{mutex__} = new POPFile::Mutex( 'mailparse_kakasi' );
-        }
-        $self->{mutex__}->acquire();
-    }
-
-    Text::Kakasi::getopt_argv("kakasi", "-w -ieuc -oeuc");
+    # Split Japanese line into words using Kakasi Wakachigaki mode
     $line = Text::Kakasi::do_kakasi($line);
-    Text::Kakasi::close_kanwadict();
-
-    if ( $need_semaphore ) {
-        $self->{mutex__}->release();
-    }
 
     return $line;
 }
 
+# ----------------------------------------------------------------------------
+#
+# init_kakasi
+#
+# Open the kanwa dictionary and initialize the parameter of Kakasi.
+#
+# ----------------------------------------------------------------------------
+sub init_kakasi
+{
+    require Text::Kakasi;
+
+    # Initialize Kakasi with Wakachigaki mode(-w is passed to 
+    # Kakasi as argument). Both input and ouput encoding are 
+    # EUC-JP.
+
+    Text::Kakasi::getopt_argv("kakasi", "-w", "-ieuc", "-oeuc");
+}
+
+# ----------------------------------------------------------------------------
+#
+# close_kakasi
+#
+# Close the kanwa dictionary of Kakasi.
+#
+# ----------------------------------------------------------------------------
+sub close_kakasi
+{
+    require Text::Kakasi;
+
+    Text::Kakasi::close_kanwadict();
+}
+
 
 1;
