@@ -9,14 +9,13 @@ use Digest::MD5;
 #
 # This module handles proxying the POP3 protocol for POPFile.
 #
-# Copyright (c) 2001-2004 John Graham-Cumming
+# Copyright (c) 2001-2006 John Graham-Cumming
 #
 #   This file is part of POPFile
 #
-#   POPFile is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
+#   POPFile is free software; you can redistribute it and/or modify it
+#   under the terms of version 2 of the GNU General Public License as
+#   published by the Free Software Foundation.
 #
 #   POPFile is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -249,7 +248,7 @@ sub child__
                 $self->mq_post_( 'LOGIN', $user );
 
                 my $ssl = defined( $options ) && ( $options =~ /ssl/i );
-                $port = 110 if ( !defined( $port ) );
+                $port = $ssl?995:110 if ( !defined( $port ) );
 
                 if ( $mail = $self->verify_connected_( $mail, $client,
                                  $host, $port, $ssl ) )  {
