@@ -7,14 +7,15 @@ use POPFile::Module;
 #
 # IMAP.pm --- a module to use POPFile for an IMAP connection.
 #
-# Copyright (c) 2001-2004 John Graham-Cumming
+# Copyright (c) 2001-2006 John Graham-Cumming
+#
+#   $Revision: 1.9.4.2 $
 #
 #   This file is part of POPFile
 #
-#   POPFile is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
+#   POPFile is free software; you can redistribute it and/or modify it
+#   under the terms of version 2 of the GNU General Public License as
+#   published by the Free Software Foundation.
 #
 #   POPFile is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -272,8 +273,11 @@ sub service
                 # all of our folders
                 $self->connect_folders__();
 
-                # Now do the real job
+                # Reset the hash containing the hash values we have seen the 
+                # last time through service.
+                $self->{hash_values__} = ();
 
+                # Now do the real job
                 foreach my $folder ( keys %{$self->{folders__}} ) {
 
                     if ( exists $self->{folders__}{$folder}{imap} ) {
@@ -282,11 +286,7 @@ sub service
 
                     }
                 }
-
-                # Reset the hash containing the hash values we have just seen.
-                $self->{hash_values__} = ();
             }
-
         };
         # if an exception occurred, we try to catch it here
         if ( $@ ) {
@@ -759,7 +759,7 @@ sub reclassify_message
     };
 
     foreach ( @lines ) {
-        print TMP "$_\n";
+        print TMP $_;
     }
     close TMP;
 
